@@ -2,7 +2,7 @@
 
 __author__ = """François Durand"""
 __email__ = 'fradurand@gmail.com'
-__version__ = '0.28.0'
+__version__ = '0.29.0'
 
 
 # Utils
@@ -24,10 +24,11 @@ from poisson_approval.utils.UtilBallots import ballot_one, ballot_two, ballot_on
 from poisson_approval.utils.UtilCache import cached_property, DeleteCacheMixin, property_deleting_cache
 from poisson_approval.utils.UtilMasks import masks_area_naive, masks_area, masks_distribution_naive, \
     masks_distribution, winners_distribution, random_mask, random_masks
+from poisson_approval.utils.UtilPlot import plt_cdf, plt_step_with_error, plt_plot_with_error
 from poisson_approval.utils.UtilPreferences import is_hater, is_lover, is_weak_order, sort_weak_order
 
 # Constants
-from poisson_approval.constants.constants import *
+from poisson_approval.constants.basic_constants import *
 from poisson_approval.constants.EquilibriumStatus import EquilibriumStatus
 from poisson_approval.constants.Focus import Focus
 
@@ -112,7 +113,16 @@ from poisson_approval.meta_analysis.binary_plots import BinaryAxesSubplotPoisson
 from poisson_approval.meta_analysis.binary_shortcuts import binary_plot_n_equilibria, \
     binary_plot_winners_at_equilibrium, binary_plot_winning_frequencies, binary_plot_convergence, \
     XyyToProfile
-from poisson_approval.meta_analysis.distribution_scores import plot_distribution_scores
+from poisson_approval.meta_analysis.convergence_test import convergence_test
+from poisson_approval.meta_analysis.is_condorcet import is_condorcet
+from poisson_approval.meta_analysis.is_not_condorcet import is_not_condorcet
+from poisson_approval.meta_analysis.monte_carlo_fictitious_play import monte_carlo_fictitious_play, \
+    MCS_BALLOT_STATISTICS, MCS_CONVERGES, MCS_DECREASING_SCORES, \
+    MCS_FREQUENCY_CW_WINS, MCS_PROFILE, MCS_TAU_INIT, MCS_WELFARE_LOSSES, \
+    MCS_UTILITY_THRESHOLDS, MCS_CANDIDATE_WINNING_FREQUENCY, MCS_N_EPISODES
+from poisson_approval.meta_analysis.plot_welfare_losses import plot_welfare_losses
+from poisson_approval.meta_analysis.plot_distribution_scores import plot_distribution_scores
+from poisson_approval.meta_analysis.plot_utility_thresholds import plot_utility_thresholds
 from poisson_approval.meta_analysis.ternary_plots import TernaryAxesSubplotPoisson, ternary_figure
 from poisson_approval.meta_analysis.ternary_shortcuts import ternary_plot_n_equilibria, \
     ternary_plot_winners_at_equilibrium, ternary_plot_winning_frequencies, ternary_plot_convergence, \
