@@ -7,7 +7,7 @@ class DictPrintingInOrderIgnoringZeros(dict):
     Notes
     -----
     All values whose boolean conversion is False are ignored when converting to string: 0, None, [], all empty
-    containers, etc. Empty numpy arrays are also ignored.
+    containers, etc. Empty `numpy` arrays are also ignored.
 
     Examples
     --------
@@ -32,6 +32,6 @@ class DictPrintingInOrderIgnoringZeros(dict):
                 not isinstance(self[key], np.ndarray) and self[key])
         ]) + "}"
 
-    def _repr_pretty_(self, p, cycle):  # pragma: no cover
+    def _repr_pretty_(self, p, cycle):  # pragma: no cover - Only for notebooks
         # https://stackoverflow.com/questions/41453624/tell-ipython-to-use-an-objects-str-instead-of-repr-for-output
         p.text(str(self) if not cycle else '...')
